@@ -1,6 +1,7 @@
 """Matter node."""
 from __future__ import annotations
 
+from dataclasses import dataclass
 import logging
 from typing import Any, TypeVar, cast
 
@@ -40,6 +41,17 @@ def get_object_params(
     raise KeyError(f"No descriptor found for object {object_id}")
 
 
+@dataclass
+class MatterFabricData:
+    """Data about a Matter fabric."""
+
+    fabric_id: int
+    vendor_id: int
+    fabric_index: int
+    fabric_label: str | None = None
+    vendor_name: str | None = None
+
+
 class MatterEndpoint:
     """Representation of a Matter Endpoint."""
 
@@ -76,7 +88,7 @@ class MatterEndpoint:
         Otherwise, returns BasicInformation from the Node itself (endpoint 0).
         """
         if self.is_bridged_device:
-            return self.get_cluster(Clusters.BridgedDeviceBasic)
+            return self.get_cluster(Clusters.BridgedDeviceBasicInformation)
         if compose_parent := self.node.get_compose_parent(self.endpoint_id):
             return compose_parent.device_info
         return self.node.device_info
@@ -188,7 +200,7 @@ class MatterEndpoint:
         cluster = self.get_cluster(Clusters.Descriptor)
         assert cluster is not None
         for dev_info in cluster.deviceTypeList:  # type: ignore[unreachable]
-            device_type = DEVICE_TYPES.get(dev_info.type)
+            device_type = DEVICE_TYPES.get(dev_info.deviceType)
             if device_type is None:
                 LOGGER.debug("Found unknown device type %s", dev_info)
                 continue
