@@ -1,5 +1,6 @@
 """Helpers to work with (de)serializing of json."""
 
+from base64 import b64encode
 from dataclasses import is_dataclass
 from typing import Any
 
@@ -30,7 +31,7 @@ def json_encoder_default(obj: Any) -> Any:
     if isinstance(obj, Nullable):
         return None
     if isinstance(obj, bytes):
-        return str(obj)
+        return b64encode(obj).decode("utf-8")
     if isinstance(obj, Exception):
         return str(obj)
     if type(obj) == type:
